pub enum MouseScrollUnit {
Line,
Pixel,
}Expand description
Indicates the unit of a mouse scroll event.
Variants
Line
The delta of the MouseScrollInput event corresponds to the amount of lines or rows to scroll.
Pixel
The delta of the MouseScrollInput event corresponds to the amount of pixels to scroll.