ButtonMap

Struct ButtonMap 

pub struct ButtonMap<T: Copy + Eq + Hash> { /* private fields */ }
Button map resource for button presses

Implementations

Source

impl<T: Copy + Eq + Hash> ButtonMap<T>

pub fn press(&mut self, input: T)

Send a button press for specified input.

pub fn release(&mut self, input: T)

Release specified input.

pub fn release_all(&mut self)

Release all currently held inputs.

pub fn reset(&mut self)

Clear all struct fields.

pub fn clear(&mut self)

Clear just_pressed and just_released inputs.

pub fn pressed(&self, input: T) -> bool

Returns true if the input is pressed.

pub fn any_pressed(&self, inputs: impl IntoIterator<Item = T>) -> bool

Returns true if any of the inputs are pressed.

pub fn all_pressed(&self, inputs: impl IntoIterator<Item = T>) -> bool

Returns true if all of the inputs are pressed.

pub fn just_pressed(&self, input: T) -> bool

Returns true if the input was just pressed.

pub fn any_just_pressed(&self, inputs: impl IntoIterator<Item = T>) -> bool

Returns true if any of the inputs have just been pressed.

pub fn all_just_pressed(&self, inputs: impl IntoIterator<Item = T>) -> bool

Reutns true if all of the inputs have just been pressed.

pub fn just_released(&self, input: T) -> bool

Returns true if the input was just released.

pub fn any_just_released(&self, inputs: impl IntoIterator<Item = T>) -> bool

Returns true if any of the inputs have just been released.

pub fn all_just_released(&self, inputs: impl IntoIterator<Item = T>) -> bool

Returns true if all of the inputs have just been released.

pub fn get_pressed(&self) -> impl ExactSizeIterator<Item = &T>

Get every pressed input.

pub fn get_just_pressed(&self) -> impl ExactSizeIterator<Item = &T>

Get every just pressed input.

pub fn get_just_released(&self) -> impl ExactSizeIterator<Item = &T>

Get every just released input.