pub struct ButtonMap<T: Copy + Eq + Hash> { /* private fields */ }Expand description
Button map resource for button presses
Implementations
Sourceimpl<T: Copy + Eq + Hash> ButtonMap<T>
impl<T: Copy + Eq + Hash> ButtonMap<T>
Sourcepub fn release_all(&mut self)
pub fn release_all(&mut self)
Release all currently held inputs.
Sourcepub fn any_pressed(&self, inputs: impl IntoIterator<Item = T>) -> bool
pub fn any_pressed(&self, inputs: impl IntoIterator<Item = T>) -> bool
Returns true if any of the inputs are pressed.
Sourcepub fn all_pressed(&self, inputs: impl IntoIterator<Item = T>) -> bool
pub fn all_pressed(&self, inputs: impl IntoIterator<Item = T>) -> bool
Returns true if all of the inputs are pressed.
Sourcepub fn just_pressed(&self, input: T) -> bool
pub fn just_pressed(&self, input: T) -> bool
Returns true if the input was just pressed.
Sourcepub fn any_just_pressed(&self, inputs: impl IntoIterator<Item = T>) -> bool
pub fn any_just_pressed(&self, inputs: impl IntoIterator<Item = T>) -> bool
Returns true if any of the inputs have just been pressed.
Sourcepub fn all_just_pressed(&self, inputs: impl IntoIterator<Item = T>) -> bool
pub fn all_just_pressed(&self, inputs: impl IntoIterator<Item = T>) -> bool
Reutns true if all of the inputs have just been pressed.
Sourcepub fn just_released(&self, input: T) -> bool
pub fn just_released(&self, input: T) -> bool
Returns true if the input was just released.
Sourcepub fn any_just_released(&self, inputs: impl IntoIterator<Item = T>) -> bool
pub fn any_just_released(&self, inputs: impl IntoIterator<Item = T>) -> bool
Returns true if any of the inputs have just been released.
Sourcepub fn all_just_released(&self, inputs: impl IntoIterator<Item = T>) -> bool
pub fn all_just_released(&self, inputs: impl IntoIterator<Item = T>) -> bool
Returns true if all of the inputs have just been released.
Sourcepub fn get_pressed(&self) -> impl ExactSizeIterator<Item = &T>
pub fn get_pressed(&self) -> impl ExactSizeIterator<Item = &T>
Get every pressed input.
Sourcepub fn get_just_pressed(&self) -> impl ExactSizeIterator<Item = &T>
pub fn get_just_pressed(&self) -> impl ExactSizeIterator<Item = &T>
Get every just pressed input.
Sourcepub fn get_just_released(&self) -> impl ExactSizeIterator<Item = &T>
pub fn get_just_released(&self) -> impl ExactSizeIterator<Item = &T>
Get every just released input.